/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_CN_RESULT_H
#define TAU_CN_RESULT_H
#include "RigidTrans3.h"
namespace TAU {
class CnResult : public RigidTrans3 {
 public:
  CnResult() : rank(0), rmsd(0.0), geomScore(0), maxPenetration(0.0), interfaceArea(0.0),
    activeSite1(0), activeSite2(0), aceScore(0)
    {}
  
  CnResult(int geom_score, float max_penetration, float interface_area,
	 int active_site1, int active_site2, float ace_score, RigidTrans3 tr):
    RigidTrans3(tr),
    rank(0), rmsd(0.0),
    geomScore(geom_score), maxPenetration(max_penetration), interfaceArea(interface_area),
    activeSite1(active_site1), activeSite2(active_site2), aceScore(ace_score)
    {}
  unsigned int getRank() const { return rank; }
  float getRMSD() const { return rmsd; }
  int getGeomScore() const { return geomScore; }
  int getScore() const { return geomScore; }
  float getMaxPenetration() const { return maxPenetration; }
  float getInterfaceArea() const { return interfaceArea; }
  float getACEScore() const { return aceScore; }
  const RigidTrans3& rigidTrans() const { return *this; }
  
 protected:
  unsigned int rank;
  float rmsd;
  int geomScore;
  float maxPenetration;
  float interfaceArea;
  int activeSite1;
  int activeSite2;
  float aceScore;
};
}
#endif
