/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_DOCK_SURFACE
#define TAU_DOCK_SURFACE
#include "ChemMolecule.h"
#include "Surface.h"
#include "GridParams.h"
#include "MoleculeGrid.h"
#include "tau_config.h"
namespace TAU {
  namespace internal {
    class DockSurface;
  }
  
  class TAUEXPORT DockSurface {
  public:
    DockSurface(const ChemMolecule& molecule, const Surface& msSurface);
    DockSurface(const DockSurface &other);
    DockSurface& operator=(const DockSurface& other);
    ~DockSurface();
    const Surface& getMsSurface() const;
    MoleculeGrid* getMoleculeGrid();
    void build_surface(const GridParams& gridParams,
                       bool ligand, float pruneThr=0.0);
    internal::DockSurface *im() { return impl_; }
  protected:
    DockSurface() : impl_(NULL), molecule_grid_(NULL) {}
    void set_im(internal::DockSurface *im) { impl_ = im; }
  private:
    internal::DockSurface *impl_;
    MoleculeGrid *molecule_grid_;
    Surface ms_surface_;
  };
}
#endif
