/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_DOCKING_TRANSFORM_PROCESSOR_H
#define TAU_DOCKING_TRANSFORM_PROCESSOR_H
#include <vector>
#include "Molecule.h"
#include "PatchSurface.h"
#include "PairwiseProgParams.h"
#include "RigidTrans3.h"
#include "tau_config.h"
namespace TAU {
  namespace internal {
    class DockingTransformsProcessor;
  }
  class TAUEXPORT DockingTransformsProcessor {
  public:
    DockingTransformsProcessor(
                  PatchSurface& inReceptor, PatchSurface& inLigand,
                  const Molecule& receptorHydrogenMolecule,
                  const Molecule& ligandHydrogenMolecule,
                  const PairwiseDockingParams& dockParams);
    DockingTransformsProcessor(const DockingTransformsProcessor &other);
    DockingTransformsProcessor& operator=(const DockingTransformsProcessor&
                                          other);
    ~DockingTransformsProcessor();
    bool isPenetrating(const RigidTrans3& trans) const;
    float scoreTransform(const RigidTrans3& trans);
    internal::DockingTransformsProcessor *impl_;
  };
}
#endif
