/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_MULTI_RESOLUTIION
#define TAU_MULTI_RESOLUTIION
#include <stack>
#include <vector>
#include "Surface.h"
#include "Vector3.h"
#include "tau_config.h"
namespace TAU {
  namespace internal {
    class SurfacePoint;
    template<class T>
    class MultiResolution;
    template<class T>
    class MultiResNode;
  }
  
  class TAUEXPORT MultiResolution {
  public:
    class TAUEXPORT Node {
      friend class MultiResolution;
    public:
      Vector3 position() const;
      short getLevel() const;
      float getRadius() const;
      unsigned int getSubtreeSize() const;
      void pushChildren(std::stack<Node> &stack);
    private:
      Node(const internal::MultiResNode<internal::SurfacePoint> *impl)
              : impl_(impl) {}
      const internal::MultiResNode<internal::SurfacePoint> *impl_;
    };
    typedef std::vector<Node> Level;
    MultiResolution(const Surface &surface,
                    float density=10.0, float gridMargins=6.0);
    MultiResolution(const MultiResolution &other);
    MultiResolution& operator=(const MultiResolution& other);
    ~MultiResolution();
    void buildTree();
    Level getLevel(int num);
    unsigned int size() const;
  private:
    internal::MultiResolution<internal::SurfacePoint> *impl_;
  };
}
#endif
