/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_PAIRWISE_PROG_PARAMS_H
#define TAU_PAIRWISE_PROG_PARAMS_H
#include <vector>
#include <string>
#include "tau_config.h"
#include "SurfaceParams.h"
namespace TAU {
struct TAUEXPORT PairwiseClusterParams {
  PairwiseClusterParams() : maxAngleDiff(0.1), ignoreClustersSmaller(4), rmsd(2.0), finalRmsd(4.0) {}
  bool add(const std::string str);
  float maxAngleDiff;
  int ignoreClustersSmaller;
  float rmsd;
  float finalRmsd;
};
struct TAUEXPORT PairwiseScoreParams {
  PairwiseScoreParams() : small_interface_ratio(0.4), max_penetration(-2.5),
    ns_thr(0.6), rec_as_thr(0.0), lig_as_thr(0.0),
    patch_res_num(500), weights(5,0) {}
  bool add(const std::string str);
  float small_interface_ratio;
  float max_penetration;
  float ns_thr;
  float rec_as_thr;
  float lig_as_thr;
  int patch_res_num;
  std::vector<int> weights;
};
struct TAUEXPORT PairwiseDesolvationParams {
  PairwiseDesolvationParams() : score_thr(500.0), cut_off_ratio(1.0) {}
  bool add(const std::string str);
  float score_thr;
  float cut_off_ratio;
};
struct TAUEXPORT MembraneLineParams {
  MembraneLineParams() {}
  bool add(const std::string str);
  int receptor_atom_index;
  int ligand_atom_index;
  float penetration_thr;
};
struct TAUEXPORT PairwiseDockingParams {
  PairwiseDockingParams() {}
  PairwiseClusterParams clusterParams;
  PairwiseScoreParams scoreParams;
  PairwiseDesolvationParams desolvationParams;
  MembraneLineParams membraneLineParams;
};
struct TAUEXPORT PairwiseAlgParams {
  PairwiseAlgParams() : protLib("chem.lib") {}
  SurfaceParams receptorParams;
  SurfaceParams ligandParams;
  PairwiseDockingParams dockingParams;
  std::string receptorPdb, ligandPdb;
  std::string receptorMs, ligandMs;
  std::string receptorActiveSite, ligandActiveSite;
  std::string receptorBlockingSite, ligandBlockingSite;
  std::string protLib;
};
class TAUEXPORT PairwiseProgParams {
 public:
  PairwiseProgParams(const char* paramFile);
  bool processParameters();
  const PairwiseAlgParams& getPairwiseAlgParams() const { return params_; }
private:
  void getParameters();
  bool parseParameterStrings();
private:
  PairwiseAlgParams params_;
  
  std::string receptorPdb_, ligandPdb_;
  std::string receptorMs_, ligandMs_;
  std::string receptorActiveSite_, ligandActiveSite_;
  std::string receptorBlockingSite_, ligandBlockingSite_;
  std::string protLib_;
  std::string receptorGrid_, ligandGrid_;
  std::string receptorSeg_, ligandSeg_;
  
  std::string distanceConstraintsParams_;
  std::string pointDistanceConstraintsParams_;
  std::string membraneLineParams_;
  std::string baseParams_;
  std::string matchingParams_;
  std::string scoreParams_;
  std::string desolvationParams_;
  std::string clusterParams_;
};
}
#endif
