/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_PARAMETERS_H
#define TAU_PARAMETERS_H
#include <iostream>
#include <string>
#include "tau_config.h"
namespace TAU {
class TAUEXPORT Parameters 
{
public:
  enum ParamType { Undef, Int, Float, Str };
  static void readParameters(std::istream& paramStream);
  
  static bool empty(); 
  static void addParameter(const std::string& paramName, const int value);
  static void addParameter(const std::string& paramName, const double value);
  static void addParameter(const std::string& paramName, const std::string& value);
  static void updateParameter(const std::string& paramName, 
                              const char* const value);
  
  static ParamType paramType(const std::string& paramName);
  static int       getInt(const std::string& paramName, const int& defaultValue=0);
  static float     getFloat(const std::string& paramName, const float& defaultValue=0.0);
  static std::string    getString(const std::string& paramName, const std::string& defaultValue=std::string());
  static void   dump(std::ostream& out);
  static void dump(FILE* outputFile);
  static std::string nextToken(std::string& str);
protected:
  Parameters();
};
}
#endif
