/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_RIGID_TRANS3_H
#define TAU_RIGID_TRANS3_H
#include "Matrix3.h"
#include "Rotation3.h"
#include <sstream>
namespace TAU {
class TAUEXPORT RigidTrans3
{
public:
  typedef Vector3::real real;
  RigidTrans3()
    : rot(1), trans()
  {}
  RigidTrans3(const Rotation3& r, const Vector3& t)
    : rot(r), trans(t)
  {}
  Rotation3 rotation_q() const {
    return Rotation3(rot);
  }
  const Vector3& translation() const {
    return trans;
  }
  friend Vector3 operator*(const RigidTrans3 &rt, const Vector3 &v) {
    return (rt.rot * v) + rt.trans;
  }
private:
  Matrix3 rot;
  Vector3 trans;
};
}
#endif
