/*
   This file is part of libTAU,
   copyright: SAMBA group, Tel-Aviv Univ. Israel, 1997.

   Distribution in binary form only is permitted for use with IMP and
   MultiFit, by permission from Prof. Haim Wolfson.
*/

#ifndef TAU_VECTOR3_H
#define TAU_VECTOR3_H
#include <stdio.h>
#include <iostream>
#include <math.h>
#include "tau_config.h"
namespace TAU {
class TAUEXPORT Vector3
{
public:
  typedef float real;
  Vector3() {
    c[0] = c[1] = c[2] = 0;
  }
  Vector3(const real& nx, const real& ny, const real& nz) {
    c[0]=nx;
    c[1]=ny;
    c[2]=nz;
  }
  const real& operator[](const unsigned short coord) const{
    return c[coord];
  }
  friend Vector3 operator+(const Vector3& p1, const Vector3& p2) {
    return Vector3(p1.c[0]+p2.c[0], p1.c[1]+p2.c[1], p1.c[2]+p2.c[2]);
  }
  friend real operator*(const Vector3& p1, const Vector3& p2) {
    return p1.c[0]*p2.c[0]+p1.c[1]*p2.c[1]+p1.c[2]*p2.c[2];
  }
  void show(std::ostream& s=std::cout) const{
    s << c[0] << ' ' << c[1] << ' ' << c[2];
  }
private:
  real c[3];  
};
}
#endif
